@@ -8,7 +8,7 @@
 
 #include <QObject>
 
-#include <KWayland/Client/kwaylandclient_export.h>
+#include "KWayland/Client/kwaylandclient_export.h"
 
 struct wl_keyboard;
 
@@ -82,6 +82,11 @@ public:
      **/
     Surface *enteredSurface();
 
+    /**
+     * @returns The keys that were reported in the enter event.
+     **/
+    QList<quint32> enteredKeys() const;
+
     /**
      * @returns Whether key repeat is enabled on this keyboard
      * @see keyRepeatRate
